@@ -284,7 +284,7 @@ Only relevant when `doom-modeline-time-analogue-clock' is non-nil, which see."
   :group 'doom-modeline)
 
 (defcustom doom-modeline-column-zero-based t
-  "When non-nil, mode line displays column numbers zero-based.
+  "When non-nil, mode line display column numbers zero-based.
 See `column-number-indicator-zero-based'."
   :type 'boolean
   :group 'doom-modeline)
@@ -345,6 +345,11 @@ It respects `doom-modeline-enable-word-count'."
   :type '(repeat (symbol :tag "Major-Mode") )
   :group 'doom-modeline)
 
+(defcustom doom-modeline-enable-buffer-position t
+  "Whether display the buffer position information."
+  :type 'boolean
+  :group 'doom-modeline)
+
 (defcustom doom-modeline-buffer-encoding t
   "Whether display the buffer encoding."
   :type '(choice (const :tag "Always" t)
@@ -374,20 +379,31 @@ It respects `doom-modeline-enable-word-count'."
   :type 'boolean
   :group 'doom-modeline)
 
+(defcustom doom-modeline-remote-host t
+  "Whether to display remote host information."
+  :type 'boolean
+  :group 'doom-modeline)
+
 ;; It is based upon `editorconfig-indentation-alist' but is used to read indentation levels instead
 ;; of setting them. (https://github.com/editorconfig/editorconfig-emacs)
 (defcustom doom-modeline-indent-alist
   '((apache-mode apache-indent-level)
     (awk-mode c-basic-offset)
+    (awk-ts-mode awk-ts-mode-indent-level)
     (bpftrace-mode c-basic-offset)
-    (c++-mode c-basic-offset)
     (c-mode c-basic-offset)
+    (c++-mode c-basic-offset)
+    (c-ts-mode c-ts-mode-indent-offset)
+    (c++-ts-mode c-ts-mode-indent-offset)
     (cmake-mode cmake-tab-width)
+    (cmake-ts-mode cmake-ts-mode-indent-offset)
     (coffee-mode coffee-tab-width)
     (cperl-mode cperl-indent-level)
     (crystal-mode crystal-indent-level)
     (csharp-mode c-basic-offset)
+    (csharp-ts-mode csharp-ts-mode-indent-offset)
     (css-mode css-indent-offset)
+    (css-ts-mode css-indent-offset)
     (d-mode c-basic-offset)
     (emacs-lisp-mode lisp-indent-offset)
     (enh-ruby-mode enh-ruby-indent-level)
@@ -414,11 +430,15 @@ It respects `doom-modeline-enable-word-count'."
                   haskell-indentation-where-post-offset
                   haskell-indentation-where-pre-offset
                   shm-indent-spaces)
+    (haskell-ts-mode)
     (haxor-mode haxor-tab-width)
     (idl-mode c-basic-offset)
     (jade-mode jade-tab-width)
     (java-mode c-basic-offset)
+    (java-ts-mode java-ts-mode-indent-offset
+                  c-ts-common-statement-offset)
     (js-mode js-indent-level)
+    (js-ts-mode js-indent-level)
     (js-jsx-mode js-indent-level
                  sgml-basic-offset)
     (js2-mode js2-basic-offset)
@@ -426,12 +446,16 @@ It respects `doom-modeline-enable-word-count'."
                   sgml-basic-offset)
     (js3-mode js3-indent-level)
     (json-mode js-indent-level)
+    (json-ts-mode json-ts-mode-indent-offset)
     (julia-mode julia-indent-offset)
+    (julia-ts-mode julia-ts-indent-offset)
     (kotlin-mode kotlin-tab-width)
+    (kotlin-mode kotlin-ts-mode-indent-offset)
     (latex-mode tex-indent-basic)
     (lisp-mode lisp-indent-offset)
     (livescript-mode livescript-tab-width)
     (lua-mode lua-indent-level)
+    (lua-ts-mode lua-ts-indent-offset)
     (matlab-mode matlab-indent-level)
     (mips-mode mips-tab-width)
     (mustache-mode mustache-basic-offset)
@@ -442,25 +466,33 @@ It respects `doom-modeline-enable-word-count'."
     (octave-mode octave-block-offset)
     (perl-mode perl-indent-level)
     (php-mode c-basic-offset)
+    (php-ts-mode php-ts-mode-indent-offset)
     (pike-mode c-basic-offset)
     (ps-mode ps-mode-tab)
     (pug-mode pug-tab-width)
     (puppet-mode puppet-indent-level)
     (python-mode python-indent-offset)
+    (python-ts-mode python-indent-offset)
     (ruby-mode ruby-indent-level)
+    (ruby-ts-mode ruby-indent-level)
     (rust-mode rust-indent-offset)
+    (rust-ts-mode rust-ts-mode-indent-offset)
     (rustic-mode rustic-indent-offset)
     (scala-mode scala-indent:step)
+    (scala-ts-mode scala-ts-indent-offset)
     (scss-mode css-indent-offset)
     (sgml-mode sgml-basic-offset)
     (sh-mode sh-basic-offset
              sh-indentation)
+    (bash-ts-mode sh-basic-offset
+                  sh-indentation)
     (slim-mode slim-indent-offset)
     (sml-mode sml-indent-level)
     (tcl-mode tcl-indent-level
               tcl-continued-indent-level)
     (terra-mode terra-indent-level)
     (typescript-mode typescript-indent-level)
+    (typescript-ts-mode typescript-ts-mode-indent-offset)
     (verilog-mode verilog-indent-level
                   verilog-indent-level-behavioral
                   verilog-indent-level-declaration
@@ -476,7 +508,8 @@ It respects `doom-modeline-enable-word-count'."
               web-mode-block-padding
               web-mode-script-padding
               web-mode-style-padding)
-    (yaml-mode yaml-indent-offset))
+    (yaml-mode yaml-indent-offset)
+    (yaml-ts-mode yaml-indent-offset))
   "Indentation retrieving variables matched to major modes.
 
 Which is used when `doom-modeline-indent-info' is non-nil.
@@ -523,14 +556,17 @@ It respects option `doom-modeline-icon'."
   :type 'boolean
   :group 'doom-modeline)
 
-(define-obsolete-variable-alias
-  'doom-modeline-checker-simple-format
-  'doom-modeline-check-simple-format
-  "4.2.0")
+(defcustom doom-modeline-check 'auto
+  "How to display the check segment.
 
-(defcustom doom-modeline-check-simple-format nil
-  "If non-nil, only display one number for check information if applicable."
-  :type 'boolean
+auto mode adapts to window width (see `doom-modeline-window-width-limit').
+full displays all detailed error information.
+simple summarizes error counts.
+nil disables the check segment."
+  :type '(choice (const :tag "Auto format" auto)
+                 (const :tag "Full format" full)
+                 (const :tag "Simple format" simple)
+                 (const :tag "Disable" nil))
   :group 'doom-modeline)
 
 (defcustom doom-modeline-number-limit 99
@@ -658,8 +694,8 @@ number, Emacs must have been idle this given time, checked after
 reach the defined timer, to fetch news.  The time step can be
 configured in `gnus-demon-timestep'."
   :type '(choice
-	  (boolean :tag "Set `doom-modeline-gnus-timer' as an idle timer")
-	  (number :tag "Set a custom idle timer"))
+	      (boolean :tag "Set `doom-modeline-gnus-timer' as an idle timer")
+	      (number :tag "Set a custom idle timer"))
   :group 'doom-modeline)
 
 (defcustom doom-modeline-gnus-excluded-groups nil
@@ -1469,14 +1505,14 @@ The face should be the first attribute, or the font family may be overridden.
 So convert the face \":family XXX :height XXX :inherit XXX\" to
 \":inherit XXX :family XXX :height XXX\".
 See https://github.com/seagle0128/doom-modeline/issues/301."
-  (when icon
+  (unless (or (null icon) (string-empty-p icon))
     (if (doom-modeline-icon-displayable-p)
         (when-let* ((props (get-text-property 0 'face icon)))
           (when (listp props)
             (cl-destructuring-bind (&key family height inherit &allow-other-keys) props
               (propertize icon 'face `(:inherit (doom-modeline ,(or face inherit props))
-                                                :family  ,(or family "")
-                                                :height  ,(or height 1.0))))))
+                                       :family  ,(or family "")
+                                       :height  ,(or height 1.0))))))
       (propertize icon 'face `(:inherit (doom-modeline ,face))))))
 
 (defun doom-modeline-icon (icon-set icon-name unicode text &rest args)
