@@ -4,8 +4,8 @@
 
 ;; Author: Vincent Zhang <seagle0128@gmail.com>
 ;; Homepage: https://github.com/seagle0128/doom-modeline
-;; Package-Version: 20251126.1552
-;; Package-Revision: 85dc5f033e05
+;; Package-Version: 20260104.316
+;; Package-Revision: d074b922ae37
 ;; Package-Requires: ((emacs "25.1") (compat "30.1.0.0") (nerd-icons "0.1.0") (shrink-path "0.3.1"))
 ;; Keywords: faces mode-line
 
@@ -75,7 +75,7 @@
 ;; or
 ;; (use-package doom-modeline
 ;;   :ensure t
-;;   :hook (after-init . doom-modeline-mode))
+;;   :init (doom-modeline-mode 1))
 ;;
 
 ;;; Code:
@@ -129,7 +129,7 @@
   '(compilation objed-state misc-info battery debug minor-modes input-method indent-info buffer-encoding major-mode time))
 
 (doom-modeline-def-modeline 'pdf
-  '(bar window-number modals matches buffer-info pdf-pages)
+  '(bar window-number modals matches buffer-info pdf-pages reader-pages)
   '(compilation misc-info major-mode process vcs time))
 
 (doom-modeline-def-modeline 'org-src
@@ -186,6 +186,7 @@ If DEFAULT is non-nil, set the default mode-line for all buffers."
     (Info-mode            . info)
     (image-mode           . media)
     (pdf-view-mode        . pdf)
+    (reader-mode          . pdf)
     (org-src-mode         . org-src)
     (paradox-menu-mode    . package)
     (xwidget-webkit-mode  . minimal)
